@@ -866,6 +866,7 @@ class Client(object):
         https_verify (bool): Should HTTPS certificates be verified (defaults to True)
         ca_cert_bundle (str): file path - if specified overrides python/system default for
             Root CA bundle that will be used.
+        auth (tuple): e.g. ("user", "pass") - see requests documentation ("auth") for details
         client_auth_cert (str): file path containing both certificate and key (unencrypted) in
             PEM format to use for TLS client authentication (passed to requests as "cert")
         user_agent (str): optional HTTP UserAgent string
@@ -886,6 +887,7 @@ class Client(object):
                  proxies=None,
                  https_verify=True,
                  ca_cert_bundle=None,
+                 auth=None,
                  client_auth_cert=None,
                  user_agent=None,
                  webservice_path="/otrs/nph-genericinterface.pl/Webservice/"):
@@ -952,6 +954,7 @@ class Client(object):
         else:
             self.https_verify = False
 
+        self.auth = auth
         self.client_auth_cert = client_auth_cert
 
         self.user_agent = user_agent
@@ -1889,8 +1892,9 @@ class Client(object):
                                         headers=headers,
                                         data=json_payload,
                                         proxies=self.proxies,
+                                        verify=self.https_verify,
                                         cert=self.client_auth_cert,
-                                        verify=self.https_verify)
+                                        auth=self.auth)
 
             # store a copy of the request
             self._request = response.request
